model
:   By default any section configured in the Barman configuration files define
    the configuration for a Barman server. If you set `model = true` in a
    section, that turns that section into a configuration model for a given
    `cluster`. Cannot be set as `false`.

    Scope: Model.
